---
title: Improving diversity and inclusion at tech (and other) events
author: mattcen
date: 2018-01-26T00:17:32+00:00
url: /2018/01/26/diverse_events/
timeline_notification:
  - 1517098498
publicize_twitter_user:
  - mattcen
categories:
  - activism
  - feminism
  - foss
  - lgbt
  - tech

---
Over the years I've attended and organised various conferences, hackathons, and other events, and it's been interesting to observe the ways in which each of them handle (or don't handle) diversity.

This post is a collection of notes and pointers about the things I've noticed are some of the most important things to help increase diversity at events. When I say diversity, I'm largely referring to the diversity of the attendees at events. People from different walks of life, backgrounds, races, genders, abilities, etc.

Being inclusive at our events is important. If our events only have homogeneous attendees, the things they focus on will only be relevant to those attendees, and not useful to anybody else. As it turns out, not everybody is a neurotypical able-bodied heterosexual middle-class cisgender white male. Those of us who do fit or approximate this description often aren't aware or appreciative of the issues experienced by anybody different from ourselves.

So, in no particular order, how do we improve diversity? This is by no means an exhaustive list, and there will be things I've missed, and perhaps some mistakes. Please check out the [references section][1] for more information. There's also a [summary at the end][2]. (EDIT: The summary is also available as a [lightning talk][3].)

## Race {#race}

<strong id="non_white">Be sensitive to and aware of non-white attendees</strong>. Ensure you call out racism in your code of conduct, and that you consider how you can be inclusive of and do outreach to various races and indigenous communities.

## Accessibility {#accessibility}

<strong id="venues">Have accessible venues.</strong> This means ensuring that all the important areas of your venue, including common areas, theatres, bathrooms and stages (speakers can have disabilities, too, and may have lots to say about them!) are wheelchair accessible.

If you think you may have people with visual or hearing disabilities at your events, <strong id="signlanguage">consider a sign-language interpreter</strong>, or having a <strong id="hearingloop">hearing-aid loop</strong>, so that these people can be involved in presentations too, and encourage presenters to be cognisant of this when making their slides (not assuming everybody can see what their slides say, for example).

Additionally, speakers should <strong id="ableist">be mindful of using [ableist language](http://www.autistichoya.com/p/ableist-words-and-terms-to-avoid.html)</strong>, or abusing terms like "OCD" to mean "fussy," for example. <strong id="website">Ensure your <i>website</i></strong> **is accessible** for people with screen readers etc.

## Dietary requirements {#dietary}

Ask for people's dietary requirements upon registration for your event. You _could_ have a set of check-boxes for things like vegetarian, vegan, gluten free, lactose free, FODMAP, etc. but regardless of whether or not you do this, you _should_ include a <strong id="dietary_freetext">dietary requirements free text field</strong> for people to explain the nuances of their situation; don't assume they'll fit into your boxes; people are complex.

## Gender {#gender}

There are more than 2 genders, and we want to be inclusive of them all. That means that beyond making our events more accessible to women, we should also be inclusive of trans, non-binary, and gender-non-conforming folks. This should include, wherever possible, <strong id="bathrooms">gender neutral bathrooms</strong>.

If your event will have name badges, and you want to give attendees input into what goes onto their name badge, then instead of permitting a "Twitter handle" text box, <strong id="badge_text">have a "free badge text; use for Twitter handle, pronoun, GitHub profile, or whatever you like" field</strong>. The mention of pronoun here demonstrates to attendees that you acknowledge people's pronouns may not match how they look (a femme presenting person may not use she/her/hers pronouns), and improves inclusion.

If you _need_ to ask for gender ensure you <strong id="gender_field">allow a free-text field to specify their gender</strong>. Again, they may not fit in your boxes. Ask, though, why you are asking for gender? Identifying diversity (e.g. how many non-men do we have at this event) is a valid reason. An argument people have made in the past is that a free text field could result in: man, male, boy, masculine, guy, woman, girl, lady, female, trans man, trans woman, unspecified, etc. This is obviously a bit tricky to aggregate for statistics, so one option is to offer an auto-complete text field that auto-completes to "female" when the user starts typing "f" or other words, for example. This _encourages_ users towards labels that make statistical aggregation easy for you, but lets them break out of your boxes if they wish, and type what they like.

Additionally, "unisex T-shirts" are not unisex. Unisex shirts are not designed properly to fit people with breasts or differently shaped chests. If you're offering T-shirts, <strong id="women_tshirts">offer women's cut shirts</strong> as well as unisex/men's cut shirts. This may also mean thinking carefully about the design you print on your shirts to <strong id="shirt_design">ensure the design looks good on people with larger chests</strong>, and that the design isn't distorted etc. Consider subtle and unintentional use of <strong id="gendered_language">gendered language</strong>, such as words like "[guys][4]."

## Names {#names}

Not everybody has a first name and a last name. Some have mononyms, other cultures display the family name first. When asking for people's names on your registration form, have a <strong id="name_field">single field for somebody's full name</strong>. Don't split it up. Ever. If you want a short or informal name (what we westerners may usually use a first name for), have an <strong id="informal_name">additional field for "informal form of address"</strong>, and explain this may be used for address in newsletters etc., so people have a context through which they can decide how to be addressed.

## Socio-economics {#socioeconomics}

Not everybody will be able to afford to come to your event. People from low socio-economic backgrounds may want to come, and have useful and interesting input and perspectives. We can't afford to exclude these people. <strong id="grants">Offer grants or sponsorships to people who can't afford to attend</strong> but wish to.

## Childcare and youth programs {#childcare_youth}

Some potential attendees will have children. <strong id="childcare">Offer childcare or youth programs</strong>. [Childcare is not hard to do][5], and demonstrates your desire to make your events family-friendly.

## Newbies {#newbies}

Going to a new event can be scary. Include details on your event's website that are easy to find and explain what to expect for your event, possibly offering a contact of whom additional questions can be asked. Once at your event, <strong id="contempt">ensure that newbies are overtly welcomed, and that <a href="http://blog.aurynn.com/contempt-culture">contempt culture</a></strong> **is discouraged**.

## Code of Conduct {#codeofconduct}

**Have a code of conduct**. There are plenty of great CoCs available (some of which I've mentioned in below in the references) off which you could base yours. It should include consequences for breaches, and details for who to contact if people feel unsafe or need to report an incident.

## Summary {#summary}

  * [Race][6] 
      * [Be sensitive to and aware of non-white attendees][7]
  * [Accessibility][8] 
      * [Have accessible venues][9]
      * [Consider a sign language interpreter][10]
      * [Consider a hearing loop for hearing aids][11]
      * [Avoid ableist language][12]
      * [Ensure your website is accessible to screen readers etc.][13]
  * [Dietary requirements][14] 
      * [Use a free text field to allow users to describe their nuanced requirements][15]
  * [Gender][16] 
      * [Have gender neutral bathrooms][17]
      * [Suggest "pronoun" as a candidate for the content of free text fields on name badges][18]
      * [Assuming you _need_ to know gender, allow free text field to specify it][19]
      * [Offer women's cut T-shirts][20], and [ensure your design looks good on all shirts while they're being worn][21]
      * [Avoid gendered language][22]
  * [Names][23] 
      * [Use single field for "full name" rather than split into first/last etc.][24]
      * [Use "informal name" field if you need it][25]
  * [Socio-economics][26] 
      * [Offer grants or sponsorship to those who can't otherwise afford attendance][27]
  * [Childcare and youth programs][28] 
      * [Offer childcare][29]
      * [Perhaps have a youth stream of activities if applicable][29]
  * [Newbies][30] 
      * [Discourage contempt culture][31]
      * [Welcome newbies, both during event promotion (on website, etc.), and at your event][31]
  * [Code of Conduct][32] 
      * [Look for and model a good CoC. See references below.][32]

## Additional references and further reading {#references}

See [Carina C. Zona's talk called "Schemas for the real world"][33] for information on how to ask for information from users without squeezing them into boxes into which they don't feel they fit. Check out the [Contributor Covenant][34], [Django Community Code of Conduct][35], the Hopper Fund's [guide to improving conference diversity][36], the [Geek Feminism anti-harassment policy][37], and the [anti-harassment policy developed by the Ada Initiative][38].

Regarding inclusive language, the Australian National LGBTI Health Alliance has an excellent [guide to inclusive sex and gender diverse language][39]. Feel free to extrapolate the guidelines for size, ability, education and ethnicity. The Australian Network on Disabilities also has a [guide to inclusive language][40] you might want to look at.

 [1]: #references
 [2]: #summary
 [3]: https://youtu.be/3MDsu6iFAD0?t=8m45s
 [4]: /guys-isnt-gender-neutral
 [5]: http://au.okfn.org/2015/08/22/childcare-at-govhack-how-it-was-done/
 [6]: #race
 [7]: #non_white
 [8]: #accessibility
 [9]: #venues
 [10]: #signlanguage
 [11]: #hearingloop
 [12]: #ableist
 [13]: #website
 [14]: #dietary
 [15]: #dietary_freetext
 [16]: #gender
 [17]: #bathrooms
 [18]: #badge_text
 [19]: #gender_field
 [20]: #women_tshirts
 [21]: #shirt_design
 [22]: #gendered_language
 [23]: #names
 [24]: #name_field
 [25]: #informal_name
 [26]: #socioeconomics
 [27]: #grants
 [28]: #childcare_youth
 [29]: #childcare
 [30]: #newbies
 [31]: #contempt
 [32]: #codeofconduct
 [33]: http://cczona.com/speaking/talks/#schemas-for-the-real-world
 [34]: https://contributor-covenant.org/
 [35]: https://www.djangoproject.com/conduct/
 [36]: http://conference.hopper.org.nz/
 [37]: http://geekfeminism.wikia.com/wiki/Conference_anti-harassment/Policy
 [38]: http://geekfeminism.wikia.com/wiki/Conference_anti-harassment
 [39]: http://lgbtihealth.org.au/sites/default/files/Alliance%20Health%20Information%20Sheet%20Inclusive%20Language%20Guide%20on%20Intersex,%20Trans%20and%20Gender%20Diversity_0.pdf
 [40]: https://www.and.org.au/pages/inclusive-language.html
